@@ -12,53 +12,67 @@ sub reflect_from {
    	my $form;
     if (exists($options->{'form'})) {
         if ( ref($options->{'form'}) eq 'HASH' ) {
-    		$form = Form::Sensible::Form->new($form);
+    		$form = Form::Sensible::Form->new($options->{'form'});
         } elsif ( ref($options->{'form'}) && 
                   UNIVERSAL::can($options->{'form'}, 'isa') &&
                   $options->{'form'}->isa('Form::Sensible::Form') ) {
+
             $form = $options->{'form'};
-        } else {
-            croak "form element provided in options, but it's not a form or a hash.  What am I supposed to do with it?";
         }
-    } else {
-        if (exists($options->{'form_name'})) {
-            $form = Form::Sensible::Form->new( name => $options->{'form_name'});
-        } else {
-            croak "No form provided, and no form name provided.  Give me something to work with?"
+        else {
+            croak
+"form element provided in options, but it's not a form or a hash.  What am I supposed to do with it?";
         }
     }
-    
-    my @fields = $self->get_fieldnames($form, $handle);
+    else {
+        if ( exists( $options->{'form_name'} ) ) {
+            $form =
+              Form::Sensible::Form->new( name => $options->{'form_name'} );
+        }
+        else {
+            croak
+"No form provided, and no form name provided.  Give me something to work with?";
+        }
+    }
+
+    my @fields = $self->get_fieldnames( $form, $handle );
+
     #my @definitions;
-    if (exists($options->{'fieldname_filter'}) && ref($options->{'fieldname_filter'}) eq 'CODE') {
+    if ( exists( $options->{'fieldname_filter'} )
+        && ref( $options->{'fieldname_filter'} ) eq 'CODE' )
+    {
         @fields = $options->{'fieldname_filter'}->(@fields);
     }
-    
-    # this little chunk of code walks a fieldmap, if provided, and ensures that there
-    # is a map entry for every field we know about.  If none was provided, it creates
-    # one for the field set to undef - which means do not add the field to the form.
+
+# this little chunk of code walks a fieldmap, if provided, and ensures that there
+# is a map entry for every field we know about.  If none was provided, it creates
+# one for the field set to undef - which means do not add the field to the form.
 
     my $fieldmap = map { $_ => $_ } @fields;
-    if (exists($options->{'fieldname_map'}) && ref($options->{'fieldname_map'}) eq 'HASH') {
+    if ( exists( $options->{'fieldname_map'} )
+        && ref( $options->{'fieldname_map'} ) eq 'HASH' )
+    {
         foreach my $field (@fields) {
-            if (exists($options->{'fieldname_map'}{$field})) {
+            if ( exists( $options->{'fieldname_map'}{$field} ) ) {
                 $fieldmap->{$field} = $options->{'fieldname_map'}{$field};
-            } else {
+            }
+            else {
                 $fieldmap->{$field} = undef;
             }
         }
     }
 
     foreach my $fieldname (@fields) {
-	   my $field_def = $self->get_field_definition($form, $handle, $fieldname);
-	   my $new_fieldname = $fieldmap->{$fieldname};
-	   warn "Processing: " . $fieldname . " as " . $new_fieldname;
-	   
-	   if ( defined($new_fieldname) ) {
-           $form->add_field($field_def, $new_fieldname);
-       }
+        my $field_def =
+          $self->get_field_definition( $form, $handle, $fieldname );
+        my $new_fieldname = $fieldmap->{$fieldname};
+        warn "Processing: " . $fieldname . " as " . $new_fieldname;
+
+        if ( defined($new_fieldname) ) {
+            $form->add_field( $field_def, $new_fieldname );
+        }
     }
-    
+
     warn "Form in create_form: " . Dumper $form;
     return $form;
 }
